#
#  Specific system configuration settings for desktop
#
#  flake.nix
#   ├─ ./hosts
#   │   └─ ./laptop
#   │        ├─ default.nix *
#   │        └─ hardware-configuration.nix       
#   └─ ./modules
#       ├─ ./desktop
#       │   └─ ./hyprland
#       │       └─ hyprland.nix
#       ├─ ./modules
#       │   └─ ./programs
#       │       └─ waybar.nix
#       └─ ./hardware
#           └─ default.nix
#

{ lib, config, pkgs, user, ... }:

{
  imports =                                                         # For now, if applying to other system, swap files
    [(import ./hardware-configuration.nix)] ++                      # Current system hardware config @ /etc/nixos/hardware-configuration.nix
    #[(import ../../modules/wm/hyprland/default.nix)] ++        # Window Manager
    [(import ../../modules/wm/sway/default.nix)] ++        # Window Manager
    [(import ../../modules/wm/virtualisation/docker.nix)] ++   # Docker
    [(import ../../modules/wm/virtualisation/kvm-intel.nix)] ++   # kvm module options
    (import ../../modules/hardware);                                # Hardware devices

  boot = {                                  # Boot options
    kernelPackages = pkgs.linuxPackages_latest;

    loader = {                              # EFI Boot
      systemd-boot.enable = lib.mkForce false;
      efi = {
        canTouchEfiVariables = true;
        efiSysMountPoint = "/boot";
      };
      timeout = 1;                          # Grub auto select time
    };

    lanzaboote = {
        enable = true;
        pkiBundle = "/etc/secureboot";
    };
  };

#  hardware.sane = {                           # Used for scanning with Xsane
#    enable = false;
#    extraBackends = [ pkgs.sane-airscan ];
#  };
  hardware = {
    nitrokey.enable = true;
  };

  environment = {
    systemPackages = with pkgs; [
       linux-firmware
       intel-media-driver
    ];
  };

  programs = {                              # No xbacklight, this is the alterantive
    light.enable = true;
  };

  systemd.sleep.extraConfig = "HibernateDelaySec=1h";
  services = {
    logind.lidSwitch = "suspend-then-hibernate";            # Laptop does not go to sleep when lid is closed
    blueman.enable = true;
    printing = {                            # Printing and drivers for TS5300
      enable = true;
      drivers = [ pkgs.gutenprint ];
    };
    avahi = {                               # Needed to find wireless printer
      enable = true;
      nssmdns4 = true;
      publish = {                           # Needed for detecting the scanner
        enable = true;
        addresses = true;
        userServices = true;
      };
    };
    #tailscale.enable = true;

  };

  #temporary bluetooth fix
#  systemd.tmpfiles.rules = [
#    "d /var/lib/bluetooth 700 root root - -"
#  ];
#  systemd.targets."bluetooth".after = ["systemd-tmpfiles-setup.service"];
}
